==> tencentcloud-sdk-java-3.1.62-sources.jar: com/tencentcloudapi/tione/v20191022/models/DeleteNotebookLifecycleScriptRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tione.v20191022.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteNotebookLifecycleScriptRequest extends AbstractModel{

    /**
    * 生命周期脚本名称
    */
    @SerializedName("NotebookLifecycleScriptsName")
    @Expose
    private String NotebookLifecycleScriptsName;

    /**
    * 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
    */
    @SerializedName("Forcible")
    @Expose
    private Boolean Forcible;

    /**
     * Get 生命周期脚本名称 
     * @return NotebookLifecycleScriptsName 生命周期脚本名称
     */
    public String getNotebookLifecycleScriptsName() {
        return this.NotebookLifecycleScriptsName;
    }

    /**
     * Set 生命周期脚本名称
     * @param NotebookLifecycleScriptsName 生命周期脚本名称
     */
    public void setNotebookLifecycleScriptsName(String NotebookLifecycleScriptsName) {
        this.NotebookLifecycleScriptsName = NotebookLifecycleScriptsName;
    }

    /**
     * Get 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false 
     * @return Forcible 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     */
    public Boolean getForcible() {
        return this.Forcible;
    }

    /**
     * Set 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     * @param Forcible 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     */
    public void setForcible(Boolean Forcible) {
        this.Forcible = Forcible;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "NotebookLifecycleScriptsName", this.NotebookLifecycleScriptsName);
        this.setParamSimple(map, prefix + "Forcible", this.Forcible);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/tione/v20191022/models/DeleteNotebookLifecycleScriptRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tione.v20191022.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteNotebookLifecycleScriptRequest extends AbstractModel{

    /**
    * 生命周期脚本名称
    */
    @SerializedName("NotebookLifecycleScriptsName")
    @Expose
    private String NotebookLifecycleScriptsName;

    /**
    * 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
    */
    @SerializedName("Forcible")
    @Expose
    private Boolean Forcible;

    /**
     * Get 生命周期脚本名称 
     * @return NotebookLifecycleScriptsName 生命周期脚本名称
     */
    public String getNotebookLifecycleScriptsName() {
        return this.NotebookLifecycleScriptsName;
    }

    /**
     * Set 生命周期脚本名称
     * @param NotebookLifecycleScriptsName 生命周期脚本名称
     */
    public void setNotebookLifecycleScriptsName(String NotebookLifecycleScriptsName) {
        this.NotebookLifecycleScriptsName = NotebookLifecycleScriptsName;
    }

    /**
     * Get 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false 
     * @return Forcible 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     */
    public Boolean getForcible() {
        return this.Forcible;
    }

    /**
     * Set 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     * @param Forcible 是否忽略已关联的 notebook 实例强行删除生命周期脚本，默认 false
     */
    public void setForcible(Boolean Forcible) {
        this.Forcible = Forcible;
    }

    public DeleteNotebookLifecycleScriptRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteNotebookLifecycleScriptRequest(DeleteNotebookLifecycleScriptRequest source) {
        if (source.NotebookLifecycleScriptsName != null) {
            this.NotebookLifecycleScriptsName = new String(source.NotebookLifecycleScriptsName);
        }
        if (source.Forcible != null) {
            this.Forcible = new Boolean(source.Forcible);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "NotebookLifecycleScriptsName", this.NotebookLifecycleScriptsName);
        this.setParamSimple(map, prefix + "Forcible", this.Forcible);

    }
}
